@@ -1,14 +1,15 @@
 #include <stdlib.h>
-#ifndef __MINGW32__
+#ifndef _WIN32
 #include <sys/mman.h>
-#endif
+#else
 #include <unistd.h>
+#endif
 #include "iarray.h"
 
 static void freechain(iarray_page* p,size_t pagesize) {
   while (p) {
     iarray_page* n=p->next;
-#ifdef __MINGW32__
+#ifdef _WIN32
     free(p);
 #else
     munmap(p,pagesize);
