@@ -5,7 +5,7 @@
 #endif
 #include "buffer.h"
 
-extern int buffer_stubborn(ssize_t (*op)(),int fd,const char* buf, size_t len,void* cookie);
+extern ssize_t buffer_stubborn(ssize_t (*op)(),int fd,const char* buf, size_t len,void* cookie);
 
 #ifndef __unlikely
 #ifdef __GNUC__
@@ -31,8 +31,8 @@ int buffer_put(buffer* b,const char* buf,size_t len) {
 	b->p=0;
 	buf+=r;
 	len-=r;
-	if (len) goto do_memcpy;
-	return 0;
+	if (!len) return 0; // wrote everything
+	// fall through
       } /* else fall through */
     }
 #endif
@@ -42,7 +42,6 @@ int buffer_put(buffer* b,const char* buf,size_t len) {
       return 0;
     }
   }
-do_memcpy:
   memcpy(b->x+b->p, buf, len);
   b->p+=len;
   return 0;
