@@ -1,7 +1,10 @@
 #include "parse.h"
 
 uint32_t prs_u32_big(struct bytestream* bs) {
-  return (bs_get(bs) << 24) | (bs_get(bs) << 16) | (bs_get(bs) << 8) | bs_get(bs);
+  uint32_t x = bs_get(bs) << 24;
+  x |= bs_get(bs) << 16;
+  x |= bs_get(bs) << 8;
+  return x | bs_get(bs);
 }
 
 #ifdef UNITTEST
