@@ -1,7 +1,7 @@
 #include "fmt.h"
 
 size_t fmt_escapecharxml(char* dest,uint32_t ch) {
-  char a[FMT_LONG], b[FMT_XLONG];
+  char a[FMT_LONG], b[FMT_XLONG+1];
   const char* s;
   size_t i,j;
   switch (ch) {
