@@ -1,10 +1,14 @@
 #include "io_internal.h"
 
+void io_wantwrite_really(int64 d, io_entry* e);
+
 void io_eagain(int64 d) {
   io_entry* e=iarray_get(&io_fds,d);
   if (e) {
     if (e->wantread) e->canread=0;
     if (e->wantwrite) e->canwrite=0;
+    if (e->wantwrite && !e->kernelwantwrite)
+      io_wantwrite_really(d,e);
 #if defined(HAVE_SIGIO)
     if (d==alt_curread) {
 #if 0
