@@ -1,9 +1,13 @@
 #include "io_internal.h"
 
+void io_wantwrite_really(int64 d, io_entry* e);
+
 void io_eagain_write(int64 d) {
   io_entry* e=iarray_get(&io_fds,d);
   if (e) {
     e->canwrite=0;
+    if (e->wantwrite && !e->kernelwantwrite)
+      io_wantwrite_really(d, e);
 #if defined(HAVE_SIGIO)
     if (d==alt_curwrite) {
 #if 0
