@@ -11,7 +11,7 @@ int io_pipe(int64* d) {
   if (pipe(fds)==-1)
     return 0;
 #endif
-  if (io_fd(fds[1]) && io_fd(fds[0])) {
+  if (io_fd_canwrite(fds[1]) && io_fd(fds[0])) {
     d[0]=fds[0];
     d[1]=fds[1];
     return 1;
