@@ -5,8 +5,8 @@
 
 int io_readwritefile(int64* d,const char* s) {
   long fd=open(s,O_RDWR);
-  if (fd != -1) {
-    *d=fd;
+  if (fd != -1) {	// gcc -fanalyze false positive
+    *d=fd;	// no leak, we return the fd in *d
     return 1;
   }
   return 0;
