@@ -15,7 +15,7 @@ int io_socketpair(int64* d) {
     if (socketpair(AF_INET6,SOCK_STREAM,IPPROTO_TCP,fds)==-1)
       if (socketpair(AF_INET,SOCK_STREAM,IPPROTO_TCP,fds)==-1)
 	return 0;
-  if (io_fd(fds[1]) && io_fd(fds[0])) {
+  if (io_fd_canwrite(fds[1]) && io_fd_canwrite(fds[0])) {
     d[0]=fds[0];
     d[1]=fds[1];
     return 1;
