@@ -27,8 +27,15 @@ int64 iob_write2(int64 s,io_batch* b,io_write_callback cb,io_sendfile_callback s
     total+=sent;
     b->bytesleft-=sent;
     if (thatsit) break;
+    // we have sent one full entry
+    if (b->autofree) {
+      if (e[i].cleanup)
+	e[i].cleanup(e+i);
+      e[i].cleanup=0;
+    }
+    ++b->next;
   }
-  if (total == b->bytesleft)
+  if (b->bytesleft == 0)
     iob_reset(b);
   return total;
 }
