@@ -1,11 +1,12 @@
+#define _POSIX_C_SOURCE 200809L
 #include "io_internal.h"
 #ifdef HAVE_EPOLL
 #include <sys/epoll.h>
 #endif
+#include <sys/time.h>
 #ifdef HAVE_KQUEUE
 #include <sys/types.h>
 #include <sys/event.h>
-#include <sys/time.h>
 #endif
 #include <errno.h>
 #ifdef __dietlibc__
@@ -14,7 +15,7 @@
 #include <semaphore.h>
 #endif
 
-// return the next event, waiting of none are queued
+// return the next event, waiting if none are queued
 // wait at most timeout milliseconds
 // on success, return 1 and return the fd in *s and the events on it in *revents
 // if we waited but ran into a timeout, return 0
@@ -78,6 +79,8 @@ int iom_wait(iomux_t* c,int64* s,unsigned int* revents,unsigned long timeout) {
 	// not transient, then they will also get an error and wake the
 	// next up
 	cnd_signal(&c->sem);
+#elif defined(__APPLE__)
+	pthread_cond_signal(&c->sem);
 #else
 	sem_post(&c->sem);
 #endif
@@ -116,6 +119,8 @@ int iom_wait(iomux_t* c,int64* s,unsigned int* revents,unsigned long timeout) {
 #ifdef __dietlibc__
 	// no dietlibc for kqueue based systems yet
 	cnd_broadcast(&c->sem);
+#elif defined(__APPLE__)
+	pthread_cond_broadcast(&c->sem);
 #else
 	sem_post(&c->sem);
 #endif
@@ -154,6 +159,11 @@ int iom_wait(iomux_t* c,int64* s,unsigned int* revents,unsigned long timeout) {
 	cnd_signal(&c->sem);
       else
 	cnd_broadcast(&c->sem);
+#elif defined(__APPLE__)
+      if (c->h == (c->l + 1) % SLOTS)
+	pthread_cond_signal(&c->sem);
+      else
+	pthread_cond_broadcast(&c->sem);
 #else
       sem_post(&c->sem);
 #endif
@@ -161,17 +171,40 @@ int iom_wait(iomux_t* c,int64* s,unsigned int* revents,unsigned long timeout) {
     } else {
       /* somebody else has the job to fill the queue */
       struct timespec ts;
-      ts.tv_sec = timeout / 1000;
-      ts.tv_nsec = (timeout % 1000) * 1000000;
+      struct timeval tv;
+      gettimeofday(&tv, NULL);
+      tv.tv_sec += timeout/1000;
+      tv.tv_usec += timeout%1000;
+      if (tv.tv_usec>1000000) {
+	tv.tv_usec-=1000000;
+	++tv.tv_sec;
+      }
+      ts.tv_sec = tv.tv_sec;
+      ts.tv_nsec = tv.tv_usec * 1000;
 #ifdef __dietlibc__
       r=cnd_timedwait(&c->sem,&c->mtx,&ts);
+      switch (r) {
+      case thrd_success:
+	continue;
+      case thrd_timedout:
+	return 0;
+      case thrd_error:
+	return -1;
+      }
+#elif defined(__APPLE__)
+      r=pthread_cond_timedwait(&c->sem,&c->mtx,&ts);
+      switch (r) {
+      case 0: continue;
+      case ETIMEDOUT: return 0;
+      default: return -1;
+      }
 #else
       r=sem_timedwait(&c->sem,&ts);
-#endif
       if (r==-1) {
 	if (errno==ETIMEDOUT) return 0;
 	return -1;
       }
+#endif
       /* fall through into next loop iteration */
     }
   }
