@@ -12,7 +12,10 @@ extern "C" {
  * map in filesize and return pointer to map. */
 const char* mmap_read(const char *filename,size_t* filesize);
 
-/* open file for writing, mmap whole file privately (copy on write),
+/* like mmap_read but use openat instead of open */
+const char* mmap_readat(const char *filename,size_t* filesize,int dirfd);
+
+/* open file for reading, mmap whole file privately (copy on write),
  * close file, write length of map in filesize and return pointer to
  * map. */
 char* mmap_private(const char *filename,size_t* filesize);
