@@ -16,3 +16,16 @@ int umult16(uint16 a,uint16 b,uint16* c) {
 }
 
 #endif
+
+
+#ifdef UNITTEST
+#include <assert.h>
+
+int main() {
+  uint16 a;
+  assert(umult16(7,10000,&a)==0);
+  assert(umult16(5,10,&a)==1 && a==50);
+  assert(umult16(6,10000,&a)==1 && a==60000);
+  return 0;
+}
+#endif
