@@ -7,7 +7,7 @@
 #endif
 
 size_t scan_8long(const char *src,unsigned long *dest) {
-  return scan_8longn(src,(size_t)-1,dest);
+  return scan_8longn(src,((size_t)-1)/2,dest);
 }
 
 #ifdef UNITTEST
