@@ -8,17 +8,16 @@
 #endif
 #include <errno.h>
 
-ssize_t socket_fastopen_connect4(int s,const char* ip,uint16 port,const char* buf,size_t len) {
-#ifndef MSG_FASTOPEN
+ssize_t socket_fastopen_connect4(int s,const char ip[4],uint16 port,const char* buf,size_t len) {
   int r;
+#ifndef MSG_FASTOPEN
   {
 #else
-  int r;
   if (len)
     r=socket_send4_flag(s,buf,len,ip,port,MSG_FASTOPEN);
   else
     r=socket_connect4(s,ip,port);
-  if (r==-1 && errno==ENOTCONN) {
+  if (r==-1 && (errno==ENOTCONN || errno==EPIPE)) {
 #endif
     /* apparently the kernel does not support TCP fast open */
     r=socket_connect4(s,ip,port);
