@@ -1,19 +1,21 @@
 #include "str.h"
 
 size_t str_chr(const char *in, char needle) {
+#if 0
   register const char* t=in;
   register const char c=needle;
   for (;;) {
-    if (!*t || *t==c) break;
-                             ++t;
-    if (!*t || *t==c) break;
-                             ++t;
-    if (!*t || *t==c) break;
-                             ++t;
-    if (!*t || *t==c) break;
-                             ++t;
+    if (!*t || *t==c) break; else ++t;
+    if (!*t || *t==c) break; else ++t;
+    if (!*t || *t==c) break; else ++t;
+    if (!*t || *t==c) break; else ++t;
   }
   return (size_t)(t-in);
+#else
+  size_t i;
+  for (i=0; in[i] && in[i]!=needle; ++i) ;
+  return i;
+#endif
 }
 
 #ifdef UNITTEST
