@@ -15,3 +15,13 @@ size_t str_len(const char* in) {
   }
   return (size_t)(t-in);
 }
+
+#ifdef UNITTEST
+#include <assert.h>
+int main() {
+  assert(str_len("foo")==3);
+  assert(str_len("")==0);
+  assert(str_len("fnord")==5);
+  return 0;
+}
+#endif
