@@ -1,7 +1,7 @@
 #include <time.h>
-#include <scan.h>
-#include <buffer.h>
-#include <fmt.h>
+#include "scan.h"
+#include "buffer.h"
+#include "fmt.h"
 
 int main() {
   char buf[100];
