@@ -1,6 +1,11 @@
 #include "io.h"
 #include <stdio.h>
+#if !defined(PTHREAD) && (defined(__dietlibc__) || defined(__linux__))
+#define THRD
 #include <threads.h>
+#else
+#include <pthread.h>
+#endif
 #include <unistd.h>
 
 iomux_t c;
@@ -9,7 +14,7 @@ int worker(void* arg) {
   uintptr_t i=(uintptr_t)arg;
   char buf[100];
   int64 s;
-  int events;
+  unsigned int events;
 
   write(1,buf,sprintf(buf,"starting thread %ld\n",i));
 
@@ -28,17 +33,32 @@ int worker(void* arg) {
   return 0;
 }
 
+#ifndef THRD
+void* workerwrapper(void* arg) {
+  return (void*)(uintptr_t)worker(arg);
+}
+#endif
+
 int main() {
   iom_init(&c);
   if (iom_add(&c,0,IOM_READ)==-1) {
     perror("iom_add");
     return 1;
   }
+#ifdef THRD
   thrd_t x[4];
+#else
+  pthread_t x[4];
+#endif
   int i;
   puts("launching threads");
   for (i=0; i<4; ++i)
-    if (thrd_create(&x[i],worker,(void*)(uintptr_t)i)==-1) {
+#ifdef THRD
+    if (thrd_create(&x[i],worker,(void*)(uintptr_t)i)==-1)
+#else
+    if (pthread_create(&x[i],0,workerwrapper,(void*)(uintptr_t)i)==-1)
+#endif
+    {
       perror("thrd_create");
       return 111;
     }
@@ -49,12 +69,23 @@ int main() {
   puts("joining threads");
   int r;
   for (i=0; i<4; ++i) {
-    if (thrd_join(x[i],&r)==-1) {
+#ifdef THRD
+    if (thrd_join(x[i],&r)==-1)
+#else
+    void* tmp;
+    
+    if (pthread_join(x[i],&tmp)!=-1)
+      r=(int)(uintptr_t)tmp;
+    else
+#endif
+    {
       perror("thrd_join");
       return 111;
     }
     printf("thread %d returned %d\n",i,r);
   }
 
+  fflush(stdout);
+
   return 0;
 }
