@@ -10,13 +10,13 @@
 #include <string.h>
 #include <sys/stat.h>
 #include <errno.h>
-#include "textcode.h"
-#include "str.h"
-#include "buffer.h"
-#include "open.h"
-#include "stralloc.h"
-#include "scan.h"
-#include "case.h"
+#include "libowfat/textcode.h"
+#include "libowfat/str.h"
+#include "libowfat/buffer.h"
+#include "libowfat/open.h"
+#include "libowfat/stralloc.h"
+#include "libowfat/scan.h"
+#include "libowfat/case.h"
 
 static const uint32_t crc_table[256] = {
   0x00000000L, 0x77073096L, 0xee0e612cL, 0x990951baL, 0x076dc419L,
