@@ -7,7 +7,7 @@ size_t fmt_ldapescape2(char* dest,const char* src,size_t len,const char* escapem
   register const unsigned char* s=(const unsigned char*) src;
   size_t written=0,i;
   for (i=0; i<len; ++i) {
-    if (s[i]=='\\' || s[i]<' ' || strchr(escapeme,s[i])) {
+    if (s[i]=='\\' || s[i]==0 || s[i]==10 || s[i]==13 || strchr(escapeme,s[i])) {
       if (dest) {
 	dest[written]='\\';
 	dest[written+1]=fmt_tohex(s[i]>>4);
