@@ -46,7 +46,7 @@ size_t scan_base64(const char *src,char *dest,size_t *destlen) {
 
 int main() {
   char buf[100];
-  size_t i,l;
+  size_t l;
   memset(buf,0,10); assert(scan_base64("Zm5vcmQ=",buf,&l)==8 && l==5 && !memcmp(buf,"fnord",6));
   /* check that we don't insist on the padding */
   memset(buf,0,10); assert(scan_base64("Zm5vcmQ",buf,&l)==7 && l==5 && !memcmp(buf,"fnord",6));
